import { 
  select, 
  csv,
	scalePoint,
  scaleLinear,
	extent,
	axisBottom,
	axisLeft,
	format } from 'd3';

const svg = select('svg');

const height = +svg.attr('height');
const width = +svg.attr('width');

const render = data => {
  
  const title = 'Relationship between experience and salary';
  const xValue = d => d.years_since_phd;
  const yValue = d => d.salary;
  const yAxisLabel = 'Salary';
  const margin = {top: 70, right: 20, bottom: 40, left: 100};
  const circleRadius = 10;
  
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleLinear()
  	.domain(extent(data, xValue))
  	.range([0, innerWidth])
  	.nice();
  
  const yScale = scaleLinear()
  	.domain(extent(data, yValue))
  	.range([0, innerHeight].reverse())
  	.nice();
  
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left}, ${margin.top})`);
  
  const yAxis = axisLeft(yScale)
  	.tickFormat(format(".2s"))
  	.tickSize(-innerWidth)
  	.tickPadding(5);
  
  const xAxis = axisBottom(xScale)
  	.tickSize(-innerHeight)
  	.tickPadding(5);
  
  const xAxisG = g.append('g').call(xAxis)
  	.attr('transform', `translate(0, ${innerHeight})`);
  
  xAxisG.selectAll('.domain').remove();
  
  const yAxisG = g.append('g').call(yAxis);
  
  yAxisG.selectAll('.domain').remove();
  
  yAxisG
    .append('text')
      .text(yAxisLabel)
      .attr('class', 'y-label')
      .attr('x', -innerHeight / 2)
      .attr('text-anchor', 'middle')
      .attr('y', -70);
  
  g.selectAll('circle').data(data).enter()
    .append('circle')
      .attr('cx', d => xScale(xValue(d)))
      .attr('cy', d => yScale(yValue(d)))
      .attr('r', circleRadius)
      .attr('rx', d => innerHeight - yScale(yValue(d)));
  
  // d => xScale.bandwidth()
  
  g.append('text')
  	.text(title)
  	.attr('y', -20)
  	.attr('class', 'title');
}

csv('data.csv').then(data => {
  data.forEach(d => {
  	d.salary = +d.salary;
    d.years_service = +d['yrs.service'];
    d.years_since_phd = +d['yrs.since.phd'];
    
    delete d['yrs.service'];
    delete d['yrs.since.phd'];
  });
  console.log(data);
	render(data)
});






















